@@ -47,7 +47,6 @@ class cppman(Crawler):
         self.failure_count = None
 
         self.blacklist = [
-            'http://www.cplusplus.com/reference/stl/'
         ]
         self.name_exceptions = [
             'http://www.cplusplus.com/reference/string/swap/'
@@ -223,12 +222,15 @@ class cppman(Crawler):
             self.cache_man_page(url, page_name)
             self.update_mandb()
 
+        pager = Environ.pager if sys.stdout.isatty() else Environ.renderer
+
         # Call viewer
         pid = os.fork()
         if pid == 0:
-            os.execl('/bin/sh', '/bin/sh', Environ.pager,
+            os.execl('/bin/sh', '/bin/sh', pager,
                      Environ.man_dir + page_name + '.3.gz',
-                     str(Formatter.get_width()), Environ.pager_config)
+                     str(Formatter.get_width()), Environ.pager_config,
+                     page_name)
         return pid
 
     def find(self, pattern):
@@ -241,10 +243,13 @@ class cppman(Crawler):
         cursor = conn.cursor()
         selected = cursor.execute('SELECT name,url FROM CPPMAN WHERE name '
                 'LIKE "%%%s%%" ORDER BY LENGTH(name)' % pattern).fetchall()
+
+        pat = re.compile('(%s)' % pattern, re.I)
+
         if selected:
             for name, url in selected:
                 if os.isatty(sys.stdout.fileno()):
-                    print name.replace(pattern, '\033[1;31m%s\033[0m' % pattern)
+                    print pat.sub(r'\033[1;31m\1\033[0m', name)
                 else:
                     print name
         else:
